==> zio-aws-lexmodelsv2_2.12-5.17.148.1-sources.jar: zio/aws/lexmodelsv2/model/LexTranscriptFilter.scala <==
package zio.aws.lexmodelsv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LexTranscriptFilter(
    dateRangeFilter: Option[zio.aws.lexmodelsv2.model.DateRangeFilter] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter = {
    import LexTranscriptFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
      .builder()
      .optionallyWith(dateRangeFilter.map(value => value.buildAwsValue()))(
        _.dateRangeFilter
      )
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly =
    zio.aws.lexmodelsv2.model.LexTranscriptFilter.wrap(buildAwsValue())
}
object LexTranscriptFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.LexTranscriptFilter =
      zio.aws.lexmodelsv2.model
        .LexTranscriptFilter(dateRangeFilter.map(value => value.asEditable))
    def dateRangeFilter
        : Option[zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly]
    def getDateRangeFilter: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly
    ] = AwsError.unwrapOptionField("dateRangeFilter", dateRangeFilter)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ) extends zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly {
    override val dateRangeFilter
        : Option[zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly] = scala
      .Option(impl.dateRangeFilter())
      .map(value => zio.aws.lexmodelsv2.model.DateRangeFilter.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ): zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lexmodelsv2_2.12-6.20.42.2-sources.jar: zio/aws/lexmodelsv2/model/LexTranscriptFilter.scala <==
package zio.aws.lexmodelsv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LexTranscriptFilter(
    dateRangeFilter: Optional[zio.aws.lexmodelsv2.model.DateRangeFilter] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter = {
    import LexTranscriptFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
      .builder()
      .optionallyWith(dateRangeFilter.map(value => value.buildAwsValue()))(
        _.dateRangeFilter
      )
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly =
    zio.aws.lexmodelsv2.model.LexTranscriptFilter.wrap(buildAwsValue())
}
object LexTranscriptFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.LexTranscriptFilter =
      zio.aws.lexmodelsv2.model
        .LexTranscriptFilter(dateRangeFilter.map(value => value.asEditable))
    def dateRangeFilter
        : Optional[zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly]
    def getDateRangeFilter: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly
    ] = AwsError.unwrapOptionField("dateRangeFilter", dateRangeFilter)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ) extends zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly {
    override val dateRangeFilter
        : Optional[zio.aws.lexmodelsv2.model.DateRangeFilter.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dateRangeFilter())
        .map(value => zio.aws.lexmodelsv2.model.DateRangeFilter.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.LexTranscriptFilter
  ): zio.aws.lexmodelsv2.model.LexTranscriptFilter.ReadOnly = new Wrapper(impl)
}
